summaryrefslogtreecommitdiff
path: root/include/ruby/impl/arithmetic/short.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/arithmetic/short.h')
-rw-r--r--include/ruby/impl/arithmetic/short.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/arithmetic/short.h b/include/ruby/impl/arithmetic/short.h
index 5eb92cff24..46d7baa046 100644
--- a/include/ruby/impl/arithmetic/short.h
+++ b/include/ruby/impl/arithmetic/short.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_ARITHMETIC_SHORT_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_ARITHMETIC_SHORT_H
+#ifndef RBIMPL_ARITHMETIC_SHORT_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_ARITHMETIC_SHORT_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -35,12 +35,12 @@
#define RB_FIX2SHORT rb_fix2short
#define FIX2SHORT RB_FIX2SHORT
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
short rb_num2short(VALUE);
unsigned short rb_num2ushort(VALUE);
short rb_fix2short(VALUE);
unsigned short rb_fix2ushort(VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
static inline short
rb_num2short_inline(VALUE x)
@@ -51,4 +51,4 @@ rb_num2short_inline(VALUE x)
return rb_num2short(x);
}
-#endif /* RUBY3_ARITHMETIC_SOHRT_H */
+#endif /* RBIMPL_ARITHMETIC_SOHRT_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file